moFeedMixers = {};
source(MultiOverlayV3.modDir.."scripte/module/feedmixers/moFeedMixersConfig.lua");

function moFeedMixers:update(dt)
	if moModule.active.feedmixers.isRunning then
		if moFeedMixers.values.updateTimer > 0 then
			if MultiOverlayV3.timers["updateFeedMixers"] ~= nil then return;end;
			moSetGetExtras:addTimer( {delay=moFeedMixers.values.updateTimer, name="updateFeedMixers", repeatable=1, ms=false, action=moFeedMixers.load} ); 
		else
			moFeedMixers:load();
		end;
	end;
end;

function moFeedMixers:load()
	moFeedMixers:loadFeedMixers();	
end;

function moFeedMixers:loadFeedMixers()
	local playerFarmId = g_currentMission.player.farmId;	
	moFeedMixers.values.feedmixers = {}; --new
	if moModule.feedMixers ~= nil and #moModule.feedMixers > 0 then
		local deleteObject = {};
		for index=1, #moModule.feedMixers do			
			if moModule.feedMixers[index] ~= nil then
				local isObject = moModule:isObject(moModule.feedMixers[index].object);
				if isObject then
					local feedmixer = moModule.feedMixers[index].object;
					if feedmixer.ownerFarmId == 0 or feedmixer.ownerFarmId == playerFarmId then
						local feedmixerName = moModule.feedMixers[index].xmlName;
						if moFeedMixers.values.feedmixers[feedmixerName] == nil then moFeedMixers.values.feedmixers[feedmixerName] = {};end;
						moFeedMixers.values.feedmixers[feedmixerName][#moFeedMixers.values.feedmixers[feedmixerName]+1] = {general={},output={},input={}};
						
						local lineTableGeneral = moFeedMixers.values.feedmixers[feedmixerName][#moFeedMixers.values.feedmixers[feedmixerName]].general;
						lineTableGeneral[#lineTableGeneral+1] = {};
						local isLineTableGeneral = lineTableGeneral[#lineTableGeneral];						
						isLineTableGeneral.object = feedmixer;
						isLineTableGeneral.objectName = moModule.feedMixers[index].name;
						isLineTableGeneral.xmlName = feedmixerName;	
						isLineTableGeneral.productivity = 0; 
						isLineTableGeneral.productivityName = moLanguageXml:getTxt("productivity", nil, g_i18n:getText("statistic_productivity"));
						isLineTableGeneral.productivityColor = 1;
						---
						local lineTableOutput = moFeedMixers.values.feedmixers[feedmixerName][#moFeedMixers.values.feedmixers[feedmixerName]].output;
						for output=1, feedmixer.numOutputs do
							local outputTable = feedmixer.outputs[output];
							lineTableOutput[#lineTableOutput+1] = {};						
							isLineTableOutput = lineTableOutput[#lineTableOutput];
							local fillType = outputTable.fillTypeTitle;
							if fillType ~= nil and string.len(fillType) > 0 then
								isLineTableOutput.fillTypeName = fillType;
							else
								isLineTableOutput.fillTypeName = moLanguageXml:getTxt("unknown", nil, "Unknown");
							end;							
							isLineTableOutput.fillTypesTotal = {outputTable.fillType};
							isLineTableOutput.fillLevel = g_i18n:formatNumber(Utils.getNoNil(outputTable.fillLevel, 0));
							isLineTableOutput.capacity = g_i18n:formatNumber(Utils.getNoNil(outputTable.capacity, 0));
							isLineTableOutput.percentageCapacity = math.floor(100 * (outputTable.fillLevel/outputTable.capacity));
							if outputTable.hasPalletSpawners then
								isLineTableOutput.palFull = outputTable.numPalletSpawners;
							end;
						end;						
						---
						local lineTableInput = moFeedMixers.values.feedmixers[feedmixerName][#moFeedMixers.values.feedmixers[feedmixerName]].input;
						local totalFillLevel = 0;
						local totalCapacity = 0;
						for input=1, feedmixer.numInputs do							
							lineTableInput[#lineTableInput+1] = {};						
							isLineTableInput = lineTableInput[#lineTableInput];
							local capacity, fillLevel, fillTypesTotal = moFeedMixers:getFillTypeLevels(feedmixer.inputs[input]);
							local fillType = moFillTypes.values.fillTypes[fillTypesTotal[1]];
							if fillType ~= nil then
								isLineTableInput.fillTypeName = fillType.name;
							else
								isLineTableInput.fillTypeName = moLanguageXml:getTxt("unknown", nil, "Unknown");
							end;							
							isLineTableInput.fillTypesTotal = fillTypesTotal;
							isLineTableInput.fillLevel = g_i18n:formatNumber(Utils.getNoNil(fillLevel, 0));
							isLineTableInput.capacity = g_i18n:formatNumber(Utils.getNoNil(capacity, 0));
							isLineTableInput.percentageCapacity = math.floor(100 * (fillLevel/capacity));
							totalFillLevel = totalFillLevel+Utils.getNoNil(fillLevel, 0);
							totalCapacity = totalCapacity+Utils.getNoNil(capacity, 0);
						end;
						if totalCapacity > 0 and totalFillLevel > 0 then
							isLineTableGeneral.productivity = g_i18n:formatNumber(Utils.getNoNil(totalFillLevel/totalCapacity, 0)*100);
							isLineTableGeneral.productivityColor = MultiOverlayV3:get_hl("getProzentColor", {Utils.getNoNil(totalFillLevel/totalCapacity, 0)*100, true}, "getProzentColor Productivity FeedMixer");
						end;
						---
					end;
				else
					table.insert(deleteObject, index);
				end;
			end;
		end;
		if #deleteObject > 0 then
			for _, index in pairs (deleteObject) do				
				table.remove(moModule.feedMixers, index);
			end;
			moModule:slotOutputCmd(true);
		end;
	end;
end;

function moFeedMixers:getFillTypeLevels(fillTypeModule)
	local fillLevelTotal = Utils.getNoNil(fillTypeModule.fillLevel, 0);
	local fillTypesTotal = {};
	local capacityTotal = Utils.getNoNil(fillTypeModule.capacity, 0);
	if fillTypeModule ~= nil and type(fillTypeModule) == "table" then
		for fillType,isAccepted in pairs(fillTypeModule.fillTypes) do
			if isAccepted then
				--fillLevelTotal = fillLevelTotal+fillType.fillLevel;
				--capacityTotal = capacityTotal+fillType.capacity;
				table.insert(fillTypesTotal, fillType);
			end;
		end;
	end;
	return capacityTotal, fillLevelTotal, fillTypesTotal;
end;
